searchData={"items":[{"type":"module","title":"ReqAthena","doc":"`Req` plugin for [AWS Athena](https://docs.aws.amazon.com/athena/latest/APIReference/Welcome.html).\n\nReqAthena makes it easy to make Athena queries. Query results are decoded into the `ReqAthena.Result` struct.\nThe struct implements the `Table.Reader` protocol and thus can be efficiently traversed by rows or columns.","ref":"ReqAthena.html"},{"type":"function","title":"ReqAthena.attach/2","doc":"Attaches to Req request.","ref":"ReqAthena.html#attach/2"},{"type":"function","title":"Request Options - ReqAthena.attach/2","doc":"* `:access_key_id` - Required. The Access Key ID from AWS credentials.\n\n  * `:secret_access_key` - Required. The Secret Access Key from AWS credentials.\n\n  * `:token` - Optional. The Session Token from AWS credentials.\n\n  * `:region` - Required. The AWS region where AWS Athena is installed.\n\n  * `:database` - Required. The AWS Athena database name.\n\n  * `:output_location` - Conditional. The S3 url location to output AWS Athena query results.\n\n  * `:workgroup` - Conditional. The AWS Athena workgroup.\n\n  * `:cache_query` - Optional. Forces a non-cached result from AWS Athena.\n\n  * `:athena` - Required. The query to execute. It can be a plain sql string or\n    a `{query, params}` tuple, where `query` can contain `?` placeholders and `params`\n    is a list of corresponding values.\n\nConditional fields must always be defined, and can be one of the fields or both.\n\nIf you want to set any of these options when attaching the plugin, pass them as the second argument.","ref":"ReqAthena.html#attach/2-request-options"},{"type":"function","title":"Examples - ReqAthena.attach/2","doc":"With plain query string:\n\n    iex> opts = [\n    ...>   access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n    ...>   secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n    ...>   region: System.fetch_env!(\"AWS_REGION\"),\n    ...>   database: \"default\",\n    ...>   output_location: System.fetch_env!(\"AWS_ATHENA_OUTPUT_LOCATION\")\n    ...> ]\n    iex> query = \"SELECT id, type, tags, members, timestamp, visible FROM planet WHERE id = 470454 and type = 'relation'\"\n    iex> req = Req.new() |> ReqAthena.attach(opts)\n    iex> Req.post!(req, athena: query).body\n    %ReqAthena.Result{\n      columns: [\"id\", \"type\", \"tags\", \"members\", \"timestamp\", \"visible\"],\n      output_location: \"s3://my-bucket/c594d5df-9879-4bf7-8796-780e0b87a673.csv\",\n      query_execution_id: \"c594d5df-9879-4bf7-8796-780e0b87a673\",\n      rows: [\n        [470454, \"relation\",\n         \"{ref=17229A, site=geodesic, name=Mérignac A, source=©IGN 2010 dans le cadre de la cartographie réglementaire, type=site, url=http://geodesie.ign.fr/fiches/index.php?module=e&action=fichepdf&source=carte&sit_no=17229A, network=NTF-5}\",\n         \"[{type=node, ref=670007839, role=}, {type=node, ref=670007840, role=}]\",\n         ~N[2017-01-21 12:51:34.000], true]\n      ],\n      statement_name: nil\n    }\n\nWith parameterized query:\n\n    iex> opts = [\n    ...>   access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n    ...>   secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n    ...>   region: System.fetch_env!(\"AWS_REGION\"),\n    ...>   database: \"default\",\n    ...>   output_location: System.fetch_env!(\"AWS_ATHENA_OUTPUT_LOCATION\")\n    ...> ]\n    iex> query = \"SELECT id, type FROM planet WHERE id = ? and type = ?\"\n    iex> req = Req.new() |> ReqAthena.attach(opts)\n    iex> Req.post!(req, athena: {query, [239_970_142, \"node\"]}).body\n    %ReqAthena.Result{\n      columns: [\"id\", \"type\"],\n      output_location: \"s3://my-bucket/dda41d66-1eea-4588-850a-945c9def9163.csv\",\n      query_execution_id: \"dda41d66-1eea-4588-850a-945c9def9163\",\n      rows: [[239_970_142, \"node\"]],\n      statement_name: \"query_C71EF77B8B7B92D9846C6D7E70136448\"\n    }","ref":"ReqAthena.html#attach/2-examples"},{"type":"function","title":"ReqAthena.fetch_option!/2","doc":"","ref":"ReqAthena.html#fetch_option!/2"},{"type":"module","title":"ReqAthena.Result","doc":"Result struct returned from any successful query.\n\nIts fields are:\n\n  * `columns` - The column names;\n  * `rows` - The result set. A list of lists, each inner list corresponding to a\n    row, each element in the inner list corresponds to a column;\n  * `statement_name` - The statement name from executed query;\n  * `query_execution_id` - The id from executed query;\n  * `output_location` - The S3 url location where the result was output.","ref":"ReqAthena.Result.html"},{"type":"type","title":"ReqAthena.Result.t/0","doc":"","ref":"ReqAthena.Result.html#t:t/0"},{"type":"extras","title":"ReqAthena","doc":"# ReqAthena\n\n[![Docs](https://img.shields.io/badge/hex.pm-docs-8e7ce6.svg)](https://hexdocs.pm/req_athena)\n[![Hex pm](http://img.shields.io/hexpm/v/req_athena.svg?style=flat&color=blue)](https://hex.pm/packages/req_athena)\n\n[Req](https://github.com/wojtekmach/req) plugin for [AWS Athena](https://docs.aws.amazon.com/athena/latest/APIReference/Welcome.html).\n\nReqAthena makes it easy to make Athena queries. Query results are decoded into the `ReqAthena.Result` struct.\nThe struct implements the `Table.Reader` protocol and thus can be efficiently traversed by rows or columns.","ref":"readme.html"},{"type":"extras","title":"Usage - ReqAthena","doc":"```elixir\nMix.install([\n  {:req, \"~> 0.3.5\"},\n  {:req_athena, \"~> 0.1.3\"}\n])\n\nopts = [\n  access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n  secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n  region: System.fetch_env!(\"AWS_REGION\"),\n  database: \"default\",\n  output_location: \"s3://my-bucket\"\n]\n\nreq = Req.new() |> ReqAthena.attach(opts)\n\n# Create table from Registry of Open Data on AWS\n# See: https://registry.opendata.aws/osm/\nquery = \\\"\"\"\nCREATE TABLE IF NOT EXISTS planet (\n  id BIGINT,\n  type STRING,\n  tags MAP ,\n  lat DECIMAL(9,7),\n  lon DECIMAL(10,7),\n  nds ARRAY >,\n  members ARRAY >,\n  changeset BIGINT,\n  timestamp TIMESTAMP,\n  uid BIGINT,\n  user STRING,\n  version BIGINT,\n  visible BOOLEAN\n)\nSTORED AS ORCFILE\nLOCATION 's3://osm-pds/planet/';\n\\\"\"\"\n\nReq.post!(req, athena: query).body\n#=>\n# %ReqAthena.Result{\n#   columns: [],\n#   output_location: \"s3://my-bucket/a034610b-daaf-4c8d-aa61-d1a706231062.txt\",\n#   query_execution_id: \"a034610b-daaf-4c8d-aa61-d1a706231062\",\n#   rows: [],\n#   statement_name: nil\n# }\n\n# With plain string query\nquery = \"SELECT id, type, tags, members, timestamp, visible FROM planet WHERE id = 470454 and type = 'relation'\"\n\nReq.post!(req, athena: query).body\n#=>\n# %ReqAthena.Result{\n#   columns: [\"id\", \"type\", \"tags\", \"members\", \"timestamp\", \"visible\"],\n#   output_location: \"s3://my-bucket/c594d5df-9879-4bf7-8796-780e0b87a673.csv\",\n#   query_execution_id: \"c594d5df-9879-4bf7-8796-780e0b87a673\",\n#   rows: [\n#     [470454, \"relation\",\n#      \"{ref=17229A, site=geodesic, name=Mérignac A, source=©IGN 2010 dans le cadre de la cartographie réglementaire, type=site, url=http://geodesie.ign.fr/fiches/index.php?module=e&action=fichepdf&source=carte&sit_no=17229A, network=NTF-5}\",\n#      \"[{type=node, ref=670007839, role=}, {type=node, ref=670007840, role=}]\",\n#      ~N[2017-01-21 12:51:34.000], true]\n#   ],\n#   statement_name: nil\n# }\n\n# With parameterized query\nquery = \"SELECT id, type FROM planet WHERE id = ? and type = ?\"\n\nReq.post!(req, athena: {query, [239_970_142, \"node\"]}).body\n#=>\n# %ReqAthena.Result{\n#   columns: [\"id\", \"type\"],\n#   output_location: \"s3://my-bucket/dda41d66-1eea-4588-850a-945c9def9163.csv\",\n#   query_execution_id: \"dda41d66-1eea-4588-850a-945c9def9163\",\n#   rows: [[239970142, \"node\"]],\n#   statement_name: \"query_C71EF77B8B7B92D9846C6D7E70136448\"\n# }\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - ReqAthena","doc":"Copyright (C) 2022 Dashbit\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown"}